summaryrefslogtreecommitdiff
path: root/src/mongo/db/repl/repl_set_commands.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/mongo/db/repl/repl_set_commands.cpp')
-rw-r--r--src/mongo/db/repl/repl_set_commands.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/mongo/db/repl/repl_set_commands.cpp b/src/mongo/db/repl/repl_set_commands.cpp
index e35ff6199d5..a02a4d32ccb 100644
--- a/src/mongo/db/repl/repl_set_commands.cpp
+++ b/src/mongo/db/repl/repl_set_commands.cpp
@@ -431,8 +431,8 @@ public:
// Convert the error code to be more specific.
uasserted(ErrorCodes::CurrentConfigNotCommittedYet, status.reason());
} else if (status == ErrorCodes::PrimarySteppedDown) {
- // Return NotMaster since the command has no side effect yet.
- status = {ErrorCodes::NotMaster, status.reason()};
+ // Return NotWritablePrimary since the command has no side effect yet.
+ status = {ErrorCodes::NotWritablePrimary, status.reason()};
}
uassertStatusOK(status);
}